@@ -1,4 +1,5 @@
-from HTMLParser import HTMLParser
+# -*- coding: utf-8 -*-
+from HTMLParser import HTMLParser, HTMLParseError
 
 
 class LinkParser(HTMLParser):
@@ -28,10 +29,19 @@ def search_attr(name, attrs):
     return []
 
 
-def extractLinks(data):
+def extractLinks(data, encoding='utf-8'):
     """ parse the given html and return all links """
+    if not data:
+        return []
     parser = LinkParser()
-    parser.feed(data)
-    parser.close()
-    return parser.getLinks()
+    try:
+        parser.feed(data)
+        parser.close()
+    except UnicodeDecodeError:
+        parser = LinkParser()
+        parser.feed(data.decode(encoding))
+        parser.close()
+    except (HTMLParseError, TypeError):
+        pass
 
+    return parser.getLinks()
